@@ -81,7 +81,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 
 static GObject	*pluma_panel_constructor	(GType type,
 						 guint n_construct_properties,
@@ -145,11 +145,7 @@ static void
 pluma_panel_focus_document (PlumaPanel *panel)
 {
 	GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (panel));
-#if !GTK_CHECK_VERSION (2, 18, 0)
-	if (GTK_WIDGET_TOPLEVEL (toplevel) && PLUMA_IS_WINDOW (toplevel))
-#else
 	if (gtk_widget_is_toplevel (toplevel) && PLUMA_IS_WINDOW (toplevel))
-#endif
 	{
 		PlumaView *view;
 
@@ -372,11 +368,7 @@ sync_title (PlumaPanel     *panel,
 
 static void
 notebook_page_changed (GtkNotebook     *notebook,
-#if GTK_CHECK_VERSION (3, 0, 0)
                        GtkWidget       *page,
-#else
-                       GtkNotebookPage *page,
-#endif
                        guint            page_num,
                        PlumaPanel      *panel)
 {
@@ -706,11 +698,7 @@ pluma_panel_add_item (PlumaPanel  *panel,
 	menu_label = gtk_label_new (name);
 	gtk_misc_set_alignment (GTK_MISC (menu_label), 0.0, 0.5);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (!gtk_widget_get_visible (item))
-#else
-	if (!GTK_WIDGET_VISIBLE (item))
-#endif
 		gtk_widget_show (item);
 
 	gtk_notebook_append_page_menu (GTK_NOTEBOOK (panel->priv->notebook),
